#!/usr/bin/env python

"""
Preparation of templating stylesheets.

Copyright (C) 2005 Paul Boddie <paul@boddie.org.uk>

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
"""

import XSLOutput
import libxml2dom
import os

resource_dir = os.path.join(os.path.split(__file__)[0], "XSL")

def make_stylesheet(template_name, output_name, stylesheet_name="Prepare.xsl", encoding="utf-8"):
    global resource_dir
    proc = XSLOutput.Processor([os.path.join(resource_dir, stylesheet_name)])
    template = libxml2dom.parse(template_name)
    proc.send_output(open(output_name, "wb"), encoding, template)

def make_stylesheet_fragment(template_name, output_name, element_id, stylesheet_name="Extract.xsl", encoding="utf-8"):
    global resource_dir
    proc = XSLOutput.Processor([os.path.join(resource_dir, stylesheet_name)], parameters={"element-id" : element_id})
    template = libxml2dom.parse(template_name)
    proc.send_output(open(output_name, "wb"), encoding, template)

def ensure_stylesheet(template_name, output_name):
    if not os.path.exists(output_name) or \
        os.path.getmtime(output_name) < os.path.getmtime(template_name):

        make_stylesheet(template_name, output_name)

def ensure_stylesheet_fragment(template_name, output_name, element_id):
    if not os.path.exists(output_name) or \
        os.path.getmtime(output_name) < os.path.getmtime(template_name):

        make_stylesheet_fragment(template_name, output_name, element_id)

# vim: tabstop=4 expandtab shiftwidth=4
